from setuptools import setup

setup(name='ax-tools',
      version='0.1',
      description='Tools for Axyl AX System',
      url='http://github.com/Omega0x013/ax-tools',
      author='Alexander Bielby',
      author_email='xanderbielby@gmail.com',
      license='GNU GPLv3',
      packages=['axm'],
      zip_safe=False)